@@ -1,4 +1,4 @@
-import numpy as np
+import numpy as np  
 import matplotlib.pyplot as plt
 from datetime import datetime, date
 
@@ -38,7 +38,7 @@ def plotJV(res, hyst=True, up=True, down=True, ax=None, **kargs):
             if UP and up or not UP and down:
                 ax.plot(Vx, getChunk(I,i)*1e3, label=["down","up"][UP])
     else:
-        ax.plot(V, I)
+        ax.plot(V, I, label=kargs.get("label",""))
     ax.set_xlabel("Voltage [V]")
     ax.set_ylabel("Current [mA]")
     return ax
